# Dual recall

This a general purpose repository for all things related to the [Dual Recall](#cite) models. The model files and scripts can be used to fit and estimate the parameters of multiple versions of the model using R packages such as [`MPTinR`][mptinr] and [`TreeBUGS`][treebugs]. See [Schmidt, Erdfelder & Heck (2023)][mpt-tutorial] for an introduction and tutorial on MPT modeling with such packages.

[mptinr]:https://doi.org/10.3758/s13428-012-0259-0
[treebugs]:https://doi.org/10.3758/s13428-017-0869-7
[mpt-tutorial]:https://dx.doi.org/10.1037/met0000561

## Table of Contents

1. [Model](#model)
1. [EQNs](#eqns)
1. [Data](#data)
1. [Scripts](#scripts)
1. [Cite](#cite)

## Model

The Dual Recall model is a theory-driven interpretation of a two-stage recall Markov chain that models recall performance over sequences of study-test cycles. The original [Trichotomous Recall][trirecall] model—an eleven free parameter recall model applied to the non-canonical STTSTST design—can be summarized by the following transition diagram:

<p align="center">
DIAGRAM
</p>

[trirecall]:https://doi.org/10.1037/a0016963

[top](#table-of-contents)

## EQNs

For short sequences of study-test cycles, the parameters of the Dual Recall model can be estimated from its multinomial processing tree (MPT) representation via an EQN file that contains the parameter and tree structure of the model. The first row of each file indicates the total number of branches in the tree, whereas all the remaining rows define the assumptions for each response category, and are organized as follows:

```txt
tree response probability
```

in which the probability is the **branch** probability. In all EQN files available here, the responses correspond to sequences of recalled (C) and not recalled (E), and are coded numerically according to the **alphabetic sorting** of the C-E string sequences. In a canonical ST-ST-ST design, for example, there will be 8 patterns of C-E responses and the codes will thus range from 1 to 8, such as CCC (`1`), CCE (`2`), CEC (`3`), ..., EEE (`8`).

In addition, all model files contain a single tree (`1`), which assumes there's a single condition. For multiple conditions, the user can edit the base EQN file to add trees for other conditions, also called joint model files. Keep in mind, however, that parameters for different conditions should have a different label (e.g., `D1expt` and `D1ctrl`), unless you're imposing between-condition restrictions (`D1expt = D1ctrl = D1`).

### Files

- TBD

### Example

```txt
26
1 1 D1
1 1 (1-D1)*R1*J1*D2
1 1 (1-D1)*R1*J1*(1-D2)*J2*D2
1 1 (1-D1)*R1*J1*(1-D2)*J2*(1-D2)*J2
1 2 (1-D1)*R1*J1*(1-D2)*J2*(1-D2)*(1-J2)
1 3 (1-D1)*R1*J1*(1-D2)*(1-J2)*D2
1 3 (1-D1)*R1*J1*(1-D2)*(1-J2)*(1-D2)*J2
1 4 (1-D1)*R1*J1*(1-D2)*(1-J2)*(1-D2)*(1-J2)
1 5 (1-D1)*R1*(1-J1)*D2
1 5 (1-D1)*R1*(1-J1)*(1-D2)*J2*D2
1 5 (1-D1)*R1*(1-J1)*(1-D2)*J2*(1-D2)*J2
1 6 (1-D1)*R1*(1-J1)*(1-D2)*J2*(1-D2)*(1-J2)
1 7 (1-D1)*R1*(1-J1)*(1-D2)*(1-J2)*D2
1 7 (1-D1)*R1*(1-J1)*(1-D2)*(1-J2)*(1-D2)*J2
1 8 (1-D1)*R1*(1-J1)*(1-D2)*(1-J2)*(1-D2)*(1-J2)
1 5 (1-D1)*(1-R1)*D2
1 5 (1-D1)*(1-R1)*(1-D2)*R2*J2*D2
1 5 (1-D1)*(1-R1)*(1-D2)*R2*J2*(1-D2)*J2
1 6 (1-D1)*(1-R1)*(1-D2)*R2*J2*(1-D2)*(1-J2)
1 7 (1-D1)*(1-R1)*(1-D2)*R2*(1-J2)*D2
1 7 (1-D1)*(1-R1)*(1-D2)*R2*(1-J2)*(1-D2)*J2
1 8 (1-D1)*(1-R1)*(1-D2)*R2*(1-J2)*(1-D2)*(1-J2)
1 7 (1-D1)*(1-R1)*(1-D2)*(1-R2)*D2
1 7 (1-D1)*(1-R1)*(1-D2)*(1-R2)*(1-D2)*R2*J2
1 8 (1-D1)*(1-R1)*(1-D2)*(1-R2)*(1-D2)*R2*(1-J2)
1 8 (1-D1)*(1-R1)*(1-D2)*(1-R2)*(1-D2)*(1-R2)
```

[top](#table-of-contents)

## Data

- TBD

[top](#table-of-contents)

## Scripts

Script templates for various languages are available on [`scripts/`](scripts/).

[top](#table-of-contents)

## Cite

- APA

    ```txt
    Gomes, C. F. A., Brainerd, C. J., Nakamura, K., & Reyna, V. F. (2014). Markovian Interpretations of Dual Retrieval Processes. Journal of Mathematical Psychology, 59, 50–64. https://doi.org/10.1016/j.jmp.2013.07.003
    ```

- BibTex

    ```txt
    @article{gomes2014markovian,
        title={Markovian interpretations of dual retrieval processes},
        author={Gomes, CFA and Brainerd, CJ and Nakamura, K and Reyna, VF},
        journal={Journal of Mathematical Psychology},
        volume={59},
        pages={50--64},
        year={2014},
        publisher={Elsevier}
    }
    ```

[top](#table-of-contents)
